@@ -21,8 +21,13 @@
 #ifndef __ED_PAINT_H__
 #define __ED_PAINT_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 struct ImBuf;
 struct Image;
+struct ImageUser;
 struct UndoStep;
 struct UndoType;
 struct bContext;
@@ -38,7 +43,7 @@ void ED_keymap_paint(struct wmKeyConfig *keyconf);
 void ED_imapaint_clear_partial_redraw(void);
 void ED_imapaint_dirty_region(struct Image *ima,
                               struct ImBuf *ibuf,
-                              int tile_number,
+                              struct ImageUser *iuser,
                               int x,
                               int y,
                               int w,
@@ -54,7 +59,7 @@ void ED_image_undo_push_begin(const char *name, int paint_mode);
 void ED_image_undo_push_begin_with_image(const char *name,
                                          struct Image *image,
                                          struct ImBuf *ibuf,
-                                         int tile_number);
+                                         struct ImageUser *iuser);
 
 void ED_image_undo_push_end(void);
 void ED_image_undo_restore(struct UndoStep *us);
@@ -64,7 +69,7 @@ void ED_image_undosys_type(struct UndoType *ut);
 void *ED_image_paint_tile_find(struct ListBase *undo_tiles,
                                struct Image *ima,
                                struct ImBuf *ibuf,
-                               int tile_number,
+                               struct ImageUser *iuser,
                                int x_tile,
                                int y_tile,
                                unsigned short **r_mask,
@@ -73,7 +78,7 @@ void *ED_image_paint_tile_push(struct ListBase *undo_tiles,
                                struct Image *ima,
                                struct ImBuf *ibuf,
                                struct ImBuf **tmpibuf,
-                               int tile_number,
+                               struct ImageUser *iuser,
                                int x_tile,
                                int y_tile,
                                unsigned short **r_mask,
@@ -96,4 +101,8 @@ void ED_paintcurve_undo_push_end(void);
 
 void ED_paintcurve_undosys_type(struct UndoType *ut);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __ED_PAINT_H__ */
