@@ -52,13 +52,10 @@ extern StructRNA RNA_ActionFCurves;
 extern StructRNA RNA_ActionGroup;
 extern StructRNA RNA_ActionGroups;
 extern StructRNA RNA_ActionPoseMarkers;
-extern StructRNA RNA_Actuator;
-extern StructRNA RNA_ActuatorSensor;
 extern StructRNA RNA_Addon;
 extern StructRNA RNA_AddonPreferences;
 extern StructRNA RNA_AdjustmentSequence;
 extern StructRNA RNA_AlwaysSensor;
-extern StructRNA RNA_AndController;
 extern StructRNA RNA_AnimData;
 extern StructRNA RNA_AnimViz;
 extern StructRNA RNA_AnimVizMotionPaths;
@@ -68,7 +65,6 @@ extern StructRNA RNA_AreaLight;
 extern StructRNA RNA_Armature;
 extern StructRNA RNA_ArmatureGpencilModifier;
 extern StructRNA RNA_ArmatureModifier;
-extern StructRNA RNA_ArmatureSensor;
 extern StructRNA RNA_ArrayGpencilModifier;
 extern StructRNA RNA_ArrayModifier;
 extern StructRNA RNA_BackgroundImage;
@@ -108,10 +104,8 @@ extern StructRNA RNA_ClothModifier;
 extern StructRNA RNA_ClothSettings;
 extern StructRNA RNA_CloudsTexture;
 extern StructRNA RNA_Collection;
-extern StructRNA RNA_CollectionEngineSettings;
 extern StructRNA RNA_CollectionProperty;
 extern StructRNA RNA_CollisionModifier;
-extern StructRNA RNA_CollisionSensor;
 extern StructRNA RNA_CollisionSettings;
 extern StructRNA RNA_ColorGpencilModifier;
 extern StructRNA RNA_ColorManagedDisplaySettings;
@@ -197,8 +191,6 @@ extern StructRNA RNA_Constraint;
 extern StructRNA RNA_ConstraintTarget;
 extern StructRNA RNA_ConstraintTargetBone;
 extern StructRNA RNA_Context;
-extern StructRNA RNA_ControlFluidSettings;
-extern StructRNA RNA_Controller;
 extern StructRNA RNA_CopyLocationConstraint;
 extern StructRNA RNA_CopyRotationConstraint;
 extern StructRNA RNA_CopyScaleConstraint;
@@ -215,19 +207,16 @@ extern StructRNA RNA_CurveProfilePoint;
 extern StructRNA RNA_DampedTrackConstraint;
 extern StructRNA RNA_DataTransferModifier;
 extern StructRNA RNA_DecimateModifier;
-extern StructRNA RNA_DelaySensor;
 extern StructRNA RNA_Depsgraph;
 extern StructRNA RNA_DepsgraphObjectInstance;
 extern StructRNA RNA_DepsgraphUpdate;
 extern StructRNA RNA_DisplaceModifier;
 extern StructRNA RNA_DisplaySafeAreas;
 extern StructRNA RNA_DistortedNoiseTexture;
-extern StructRNA RNA_DomainFluidSettings;
 extern StructRNA RNA_DopeSheet;
 extern StructRNA RNA_Driver;
 extern StructRNA RNA_DriverTarget;
 extern StructRNA RNA_DriverVariable;
-extern StructRNA RNA_DupliGpencilModifier;
 extern StructRNA RNA_DynamicPaintBrushSettings;
 extern StructRNA RNA_DynamicPaintCanvasSettings;
 extern StructRNA RNA_DynamicPaintModifier;
@@ -240,7 +229,6 @@ extern StructRNA RNA_EnumProperty;
 extern StructRNA RNA_EnumPropertyItem;
 extern StructRNA RNA_Event;
 extern StructRNA RNA_ExplodeModifier;
-extern StructRNA RNA_ExpressionController;
 extern StructRNA RNA_FCurve;
 extern StructRNA RNA_FCurveSample;
 extern StructRNA RNA_FFmpegSettings;
@@ -260,7 +248,10 @@ extern StructRNA RNA_FileBrowserFSMenuEntry;
 extern StructRNA RNA_FileSelectParams;
 extern StructRNA RNA_FloatProperty;
 extern StructRNA RNA_FloorConstraint;
-extern StructRNA RNA_FluidFluidSettings;
+extern StructRNA RNA_FluidDomainSettings;
+extern StructRNA RNA_FluidEffectorSettings;
+extern StructRNA RNA_FluidFlowSettings;
+extern StructRNA RNA_FluidModifier;
 extern StructRNA RNA_FluidSettings;
 extern StructRNA RNA_FollowPathConstraint;
 extern StructRNA RNA_FreestyleLineSet;
@@ -283,8 +274,8 @@ extern StructRNA RNA_GizmoProperties;
 extern StructRNA RNA_GlowSequence;
 extern StructRNA RNA_GpencilModifier;
 extern StructRNA RNA_GreasePencil;
+extern StructRNA RNA_Hair;
 extern StructRNA RNA_Header;
-extern StructRNA RNA_HemiLight;
 extern StructRNA RNA_Histogram;
 extern StructRNA RNA_HookGpencilModifier;
 extern StructRNA RNA_HookModifier;
@@ -299,17 +290,14 @@ extern StructRNA RNA_ImagePreview;
 extern StructRNA RNA_ImageSequence;
 extern StructRNA RNA_ImageTexture;
 extern StructRNA RNA_ImageUser;
-extern StructRNA RNA_InflowFluidSettings;
 extern StructRNA RNA_IntProperty;
 extern StructRNA RNA_Itasc;
-extern StructRNA RNA_JoystickSensor;
 extern StructRNA RNA_Key;
 extern StructRNA RNA_KeyConfig;
 extern StructRNA RNA_KeyConfigPreferences;
 extern StructRNA RNA_KeyMap;
 extern StructRNA RNA_KeyMapItem;
 extern StructRNA RNA_KeyMapItems;
-extern StructRNA RNA_KeyboardSensor;
 extern StructRNA RNA_Keyframe;
 extern StructRNA RNA_KeyingSet;
 extern StructRNA RNA_KeyingSetInfo;
@@ -327,8 +315,6 @@ extern StructRNA RNA_LayerObjects;
 extern StructRNA RNA_Library;
 extern StructRNA RNA_Light;
 extern StructRNA RNA_LightProbe;
-extern StructRNA RNA_LightSkySettings;
-extern StructRNA RNA_LightTextureSlot;
 extern StructRNA RNA_LimitDistanceConstraint;
 extern StructRNA RNA_LimitLocationConstraint;
 extern StructRNA RNA_LimitRotationConstraint;
@@ -387,19 +373,15 @@ extern StructRNA RNA_MaskLayer;
 extern StructRNA RNA_MaskModifier;
 extern StructRNA RNA_MaskSequence;
 extern StructRNA RNA_Material;
-extern StructRNA RNA_MaterialRaytraceMirror;
 extern StructRNA RNA_MaterialSlot;
 extern StructRNA RNA_Menu;
 extern StructRNA RNA_Mesh;
 extern StructRNA RNA_MeshCacheModifier;
 extern StructRNA RNA_MeshColor;
-extern StructRNA RNA_MeshColorLayer;
 extern StructRNA RNA_MeshDeformModifier;
 extern StructRNA RNA_MeshEdge;
 extern StructRNA RNA_MeshFloatProperty;
-extern StructRNA RNA_MeshFloatPropertyLayer;
 extern StructRNA RNA_MeshIntProperty;
-extern StructRNA RNA_MeshIntPropertyLayer;
 extern StructRNA RNA_MeshLoop;
 extern StructRNA RNA_MeshLoopColor;
 extern StructRNA RNA_MeshLoopColorLayer;
@@ -408,16 +390,11 @@ extern StructRNA RNA_MeshPolygon;
 extern StructRNA RNA_MeshSequenceCacheModifier;
 extern StructRNA RNA_MeshSkinVertex;
 extern StructRNA RNA_MeshSkinVertexLayer;
-extern StructRNA RNA_MeshSticky;
 extern StructRNA RNA_MeshStringProperty;
-extern StructRNA RNA_MeshStringPropertyLayer;
 extern StructRNA RNA_MeshTextureFace;
-extern StructRNA RNA_MeshTextureFaceLayer;
 extern StructRNA RNA_MeshTexturePoly;
-extern StructRNA RNA_MeshTexturePolyLayer;
 extern StructRNA RNA_MeshUVLoop;
 extern StructRNA RNA_MeshVertex;
-extern StructRNA RNA_MessageSensor;
 extern StructRNA RNA_MetaBall;
 extern StructRNA RNA_MetaElement;
 extern StructRNA RNA_MetaSequence;
@@ -426,7 +403,6 @@ extern StructRNA RNA_MirrorModifier;
 extern StructRNA RNA_Modifier;
 extern StructRNA RNA_MotionPath;
 extern StructRNA RNA_MotionPathVert;
-extern StructRNA RNA_MouseSensor;
 extern StructRNA RNA_MovieClipSequence;
 extern StructRNA RNA_MovieSequence;
 extern StructRNA RNA_MovieTracking;
@@ -437,8 +413,6 @@ extern StructRNA RNA_MulticamSequence;
 extern StructRNA RNA_MultiplyGpencilModifier;
 extern StructRNA RNA_MultiresModifier;
 extern StructRNA RNA_MusgraveTexture;
-extern StructRNA RNA_NandController;
-extern StructRNA RNA_NearSensor;
 extern StructRNA RNA_NlaStrip;
 extern StructRNA RNA_NlaTrack;
 extern StructRNA RNA_Node;
@@ -451,15 +425,12 @@ extern StructRNA RNA_NodeSocketInterface;
 extern StructRNA RNA_NodeTree;
 extern StructRNA RNA_NoiseGpencilModifier;
 extern StructRNA RNA_NoiseTexture;
-extern StructRNA RNA_NorController;
 extern StructRNA RNA_NormalEditModifier;
 extern StructRNA RNA_Object;
 extern StructRNA RNA_ObjectBase;
 extern StructRNA RNA_ObjectDisplay;
-extern StructRNA RNA_ObstacleFluidSettings;
 extern StructRNA RNA_OceanModifier;
 extern StructRNA RNA_OceanTexData;
-extern StructRNA RNA_OceanTexture;
 extern StructRNA RNA_OffsetGpencilModifier;
 extern StructRNA RNA_OpacityGpencilModifier;
 extern StructRNA RNA_Operator;
@@ -468,8 +439,6 @@ extern StructRNA RNA_OperatorMacro;
 extern StructRNA RNA_OperatorMousePath;
 extern StructRNA RNA_OperatorProperties;
 extern StructRNA RNA_OperatorStrokeElement;
-extern StructRNA RNA_OrController;
-extern StructRNA RNA_OutflowFluidSettings;
 extern StructRNA RNA_PackedFile;
 extern StructRNA RNA_Paint;
 extern StructRNA RNA_PaintCurve;
@@ -481,7 +450,6 @@ extern StructRNA RNA_Particle;
 extern StructRNA RNA_ParticleBrush;
 extern StructRNA RNA_ParticleDupliWeight;
 extern StructRNA RNA_ParticleEdit;
-extern StructRNA RNA_ParticleFluidSettings;
 extern StructRNA RNA_ParticleHairKey;
 extern StructRNA RNA_ParticleInstanceModifier;
 extern StructRNA RNA_ParticleKey;
@@ -492,6 +460,7 @@ extern StructRNA RNA_ParticleSystemModifier;
 extern StructRNA RNA_ParticleTarget;
 extern StructRNA RNA_PivotConstraint;
 extern StructRNA RNA_PointCache;
+extern StructRNA RNA_PointCloud;
 extern StructRNA RNA_PointLight;
 extern StructRNA RNA_PointerProperty;
 extern StructRNA RNA_Pose;
@@ -503,20 +472,12 @@ extern StructRNA RNA_PreferencesInput;
 extern StructRNA RNA_PreferencesKeymap;
 extern StructRNA RNA_PreferencesSystem;
 extern StructRNA RNA_PreferencesView;
-extern StructRNA RNA_PreferencesWalkNavigation;
 extern StructRNA RNA_Property;
 extern StructRNA RNA_PropertyGroup;
 extern StructRNA RNA_PropertyGroupItem;
-extern StructRNA RNA_PropertySensor;
 extern StructRNA RNA_PythonConstraint;
-extern StructRNA RNA_PythonController;
-extern StructRNA RNA_RadarSensor;
-extern StructRNA RNA_RandomSensor;
-extern StructRNA RNA_RaySensor;
 extern StructRNA RNA_Region;
 extern StructRNA RNA_RenderEngine;
-extern StructRNA RNA_RenderEngineSettings;
-extern StructRNA RNA_RenderEngineSettingsClay;
 extern StructRNA RNA_RenderLayer;
 extern StructRNA RNA_RenderPass;
 extern StructRNA RNA_RenderResult;
@@ -560,15 +521,10 @@ extern StructRNA RNA_ShaderFxWave;
 extern StructRNA RNA_ShaderNode;
 extern StructRNA RNA_ShaderNodeCameraData;
 extern StructRNA RNA_ShaderNodeCombineRGB;
-extern StructRNA RNA_ShaderNodeExtendedMaterial;
 extern StructRNA RNA_ShaderNodeGamma;
-extern StructRNA RNA_ShaderNodeGeometry;
 extern StructRNA RNA_ShaderNodeHueSaturation;
-extern StructRNA RNA_ShaderNodeIESLight;
 extern StructRNA RNA_ShaderNodeInvert;
-extern StructRNA RNA_ShaderNodeLightData;
 extern StructRNA RNA_ShaderNodeMapping;
-extern StructRNA RNA_ShaderNodeMaterial;
 extern StructRNA RNA_ShaderNodeMath;
 extern StructRNA RNA_ShaderNodeMixRGB;
 extern StructRNA RNA_ShaderNodeNormal;
@@ -579,8 +535,6 @@ extern StructRNA RNA_ShaderNodeRGBCurve;
 extern StructRNA RNA_ShaderNodeRGBToBW;
 extern StructRNA RNA_ShaderNodeScript;
 extern StructRNA RNA_ShaderNodeSeparateRGB;
-extern StructRNA RNA_ShaderNodeSqueeze;
-extern StructRNA RNA_ShaderNodeTexture;
 extern StructRNA RNA_ShaderNodeTree;
 extern StructRNA RNA_ShaderNodeValToRGB;
 extern StructRNA RNA_ShaderNodeValue;
@@ -595,10 +549,6 @@ extern StructRNA RNA_ShrinkwrapModifier;
 extern StructRNA RNA_SimpleDeformModifier;
 extern StructRNA RNA_SimplifyGpencilModifier;
 extern StructRNA RNA_SkinModifier;
-extern StructRNA RNA_FluidEffectorSettings;
-extern StructRNA RNA_FluidDomainSettings;
-extern StructRNA RNA_FluidFlowSettings;
-extern StructRNA RNA_FluidModifier;
 extern StructRNA RNA_SmoothGpencilModifier;
 extern StructRNA RNA_SmoothModifier;
 extern StructRNA RNA_SoftBodyModifier;
@@ -675,7 +625,6 @@ extern StructRNA RNA_TextureNodeValToRGB;
 extern StructRNA RNA_TextureNodeViewer;
 extern StructRNA RNA_TextureSlot;
 extern StructRNA RNA_Theme;
-extern StructRNA RNA_ThemeAudioWindow;
 extern StructRNA RNA_ThemeBoneColorSet;
 extern StructRNA RNA_ThemeConsole;
 extern StructRNA RNA_ThemeDopeSheet;
@@ -684,7 +633,6 @@ extern StructRNA RNA_ThemeFontStyle;
 extern StructRNA RNA_ThemeGraphEditor;
 extern StructRNA RNA_ThemeImageEditor;
 extern StructRNA RNA_ThemeInfo;
-extern StructRNA RNA_ThemeLogicEditor;
 extern StructRNA RNA_ThemeNLAEditor;
 extern StructRNA RNA_ThemeNodeEditor;
 extern StructRNA RNA_ThemeOutliner;
@@ -720,6 +668,7 @@ extern StructRNA RNA_UVWarpModifier;
 extern StructRNA RNA_UnitSettings;
 extern StructRNA RNA_UnknownType;
 extern StructRNA RNA_UserSolidLight;
+extern StructRNA RNA_VertexcolorGpencilModifier;
 extern StructRNA RNA_VectorFont;
 extern StructRNA RNA_VertexGroup;
 extern StructRNA RNA_VertexGroupElement;
@@ -731,25 +680,25 @@ extern StructRNA RNA_View3DCursor;
 extern StructRNA RNA_View3DOverlay;
 extern StructRNA RNA_View3DShading;
 extern StructRNA RNA_ViewLayer;
+extern StructRNA RNA_ViewLayerEEVEE;
+extern StructRNA RNA_Volume;
 extern StructRNA RNA_VoronoiTexture;
 extern StructRNA RNA_WalkNavigation;
 extern StructRNA RNA_WarpModifier;
 extern StructRNA RNA_WaveModifier;
 extern StructRNA RNA_WeightedNormalModifier;
+extern StructRNA RNA_WeldModifier;
 extern StructRNA RNA_Window;
 extern StructRNA RNA_WindowManager;
 extern StructRNA RNA_WipeSequence;
 extern StructRNA RNA_WireframeModifier;
-extern StructRNA RNA_WeldModifier;
 extern StructRNA RNA_WoodTexture;
 extern StructRNA RNA_WorkSpace;
 extern StructRNA RNA_World;
-extern StructRNA RNA_WorldAmbientOcclusion;
 extern StructRNA RNA_WorldLighting;
 extern StructRNA RNA_WorldMistSettings;
-extern StructRNA RNA_WorldTextureSlot;
-extern StructRNA RNA_XnorController;
-extern StructRNA RNA_XorController;
+extern StructRNA RNA_XrSessionSettings;
+extern StructRNA RNA_XrSessionState;
 extern StructRNA RNA_uiPopover;
 extern StructRNA RNA_wmOwnerIDs;
 
